@@ -194,6 +194,7 @@ void dump_config(struct runctl *runp, struct query *querylist)
     booldump("bouncemail", runp->bouncemail);
     stringdump("properties", runp->properties);
     booldump("invisible", runp->invisible);
+    booldump("showdots", runp->showdots);
     booldump("syslog", runp->use_syslog);
 
     if (!querylist)
@@ -290,6 +291,7 @@ void dump_config(struct runctl *runp, struct query *querylist)
 
 	    stringdump("plugin", ctl->server.plugin);
 	    stringdump("plugout", ctl->server.plugout);
+	    stringdump("principal", ctl->server.principal);
 
 	    indent(0);
 	    fputs("'users': ", stdout);
