@@ -434,7 +434,7 @@ static int readheaders(int sock,
     int			from_offs, reply_to_offs, resent_from_offs;
     int			app_from_offs, sender_offs, resent_sender_offs;
     int			env_offs;
-    char		*received_for, *rcv, *cp;
+    char		*received_for, *rcv, *cp, *delivered_to;
     int 		n, linelen, oldlen, ch, remaining, skipcount;
     struct idlist 	*idp;
     flag		no_local_matches = FALSE;
@@ -458,7 +458,7 @@ static int readheaders(int sock,
     if (msgblk.headers)
        free(msgblk.headers);
 
-    msgblk.headers = received_for = NULL;
+    msgblk.headers = received_for = delivered_to = NULL;
     from_offs = reply_to_offs = resent_from_offs = app_from_offs = 
 	sender_offs = resent_sender_offs = env_offs = -1;
     oldlen = 0;
@@ -479,6 +479,7 @@ static int readheaders(int sock,
 		set_timeout(0);
 		free(line);
 		free(msgblk.headers);
+		msgblk.headers = NULL;
 		return(PS_SOCKET);
 	    }
 	    set_timeout(0);
@@ -543,7 +544,7 @@ static int readheaders(int sock,
 	    sizeticker += linelen;
 	    while (sizeticker >= SIZETICKER)
 	    {
-		if (!run.use_syslog && !isafile(1))
+		if ((!run.use_syslog && !isafile(1)) || run.showdots)
 		{
 		    fputc('.', stdout);
 		    fflush(stdout);
@@ -617,6 +618,7 @@ static int readheaders(int sock,
 	    if (num == 1 && !strncasecmp(line, "X-IMAP:", 7)) {
 		free(line);
 		free(msgblk.headers);
+		msgblk.headers = NULL;
 		return(PS_RETAINED);
 	    }
 
@@ -656,7 +658,8 @@ static int readheaders(int sock,
 	 * Should be controlled by an option
 	 */
 	if (ctl->dropdelivered && !strncasecmp(line, "Delivered-To:", 13)) {
-	  free(line);
+      if (delivered_to) free(line);
+      else delivered_to = line;
 	  continue;
 	}
 
@@ -924,6 +927,12 @@ static int readheaders(int sock,
 #endif /* SDPS_ENABLE */ 
 	if (env_offs > -1)	    /* We have the actual envelope addressee */
 	    find_server_names(msgblk.headers + env_offs, ctl, &msgblk.recipients);
+	else if (delivered_to && ctl->server.envelope != STRING_DISABLED &&
+      ctl->server.envelope && !strcasecmp(ctl->server.envelope, "Delivered-To"))
+   {
+	    find_server_names(delivered_to, ctl, &msgblk.recipients);
+       free(delivered_to);
+   }
 	else if (received_for)
 	    /*
 	     * We have the Received for addressee.  
@@ -985,6 +994,7 @@ static int readheaders(int sock,
 	    report(stdout,
 		   _("forwarding and deletion suppressed due to DNS errors\n"));
 	free(msgblk.headers);
+	msgblk.headers = NULL;
 	free_str_list(&msgblk.recipients);
 	return(PS_TRANSIENT);
     }
@@ -995,6 +1005,7 @@ static int readheaders(int sock,
 			   &good_addresses, &bad_addresses)) != PS_SUCCESS)
 	{
 	    free(msgblk.headers);
+	    msgblk.headers = NULL;
 	    free_str_list(&msgblk.recipients);
 	    return(n);
 	}
@@ -1092,6 +1103,7 @@ static int readheaders(int sock,
 	report(stdout, _("writing RFC822 msgblk.headers\n"));
 	release_sink(ctl);
 	free(msgblk.headers);
+	msgblk.headers = NULL;
 	free_str_list(&msgblk.recipients);
 	return(PS_IOERR);
     }
@@ -1205,7 +1217,7 @@ static int readbody(int sock, struct query *ctl, flag forward, int len)
 	    sizeticker += linelen;
 	    while (sizeticker >= SIZETICKER)
 	    {
-		if ((run.poll_interval == 0 || nodetach) && outlevel > O_SILENT && !isafile(1))
+		if (outlevel > O_SILENT && (((run.poll_interval == 0 || nodetach) && !isafile(1)) || run.showdots))
 		{
 		    fputc('.', stdout);
 		    fflush(stdout);
@@ -1276,7 +1288,7 @@ static int readbody(int sock, struct query *ctl, flag forward, int len)
 
 #ifdef KERBEROS_V4
 int
-kerberos_auth (socket, canonical) 
+kerberos_auth (socket, canonical, principal) 
 /* authenticate to the server host using Kerberos V4 */
 int socket;		/* socket to server host */
 #if defined(__FreeBSD__) || defined(__OpenBSD__)
@@ -1284,6 +1296,7 @@ char *canonical;	/* server name */
 #else
 const char *canonical;	/* server name */
 #endif
+char *principal;
 {
     char * host_primary;
     KTEXT ticket;
@@ -1291,11 +1304,36 @@ const char *canonical;	/* server name */
     CREDENTIALS cred;
     Key_schedule schedule;
     int rem;
+    char * prin_copy = (char *) NULL;
+    char * prin = (char *) NULL;
+    char * inst = (char *) NULL;
+    char * realm = (char *) NULL;
+
+    if (principal != (char *)NULL && *principal)
+    {
+        char *cp;
+        prin = prin_copy = xstrdup(principal);
+	for (cp = prin_copy; *cp && *cp != '.'; ++cp)
+	    ;
+	if (*cp)
+	{
+	    *cp++ = '\0';
+	    inst = cp;
+	    while (*cp && *cp != '@')
+	        ++cp;
+	    if (*cp)
+	    {
+	        *cp++ = '\0';
+	        realm = cp;
+	    }
+	}
+    }
   
     xalloca(ticket, KTEXT, sizeof (KTEXT_ST));
-    rem = (krb_sendauth (0L, socket, ticket, "pop",
-			 canonical,
-			 ((char *) (krb_realmofhost (canonical))),
+    rem = (krb_sendauth (0L, socket, ticket,
+			 prin ? prin : "pop",
+			 inst ? inst : canonical,
+			 realm ? realm : ((char *) (krb_realmofhost (canonical))),
 			 ((unsigned long) 0),
 			 (&msg_data),
 			 (&cred),
@@ -1303,6 +1341,10 @@ const char *canonical;	/* server name */
 			 ((struct sockaddr_in *) 0),
 			 ((struct sockaddr_in *) 0),
 			 "KPOPV0.1"));
+    if (prin_copy)
+    {
+        free(prin_copy);
+    }
     if (rem != KSUCCESS)
     {
 	report(stderr, _("kerberos error %s\n"), (krb_get_err_text (rem)));
@@ -1723,7 +1765,8 @@ const int maxfetch;		/* maximum number of messages to fetch */
 	if (ctl->server.preauthenticate == A_KERBEROS_V4)
 	{
 	    set_timeout(mytimeout);
-	    ok = kerberos_auth(mailserver_socket, ctl->server.truename);
+	    ok = kerberos_auth(mailserver_socket, ctl->server.truename,
+			       ctl->server.principal);
 	    set_timeout(0);
  	    if (ok != 0)
 		goto cleanUp;
