@@ -102,7 +102,7 @@ static void unlockit(void)
 	unlink(lockfile);
 }
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) && defined(__FreeBSD_USE_KVM)
 /* drop SGID kmem privileage until we need it */
 static void dropprivs(void)
 {
@@ -152,7 +152,7 @@ int main(int argc, char **argv)
     pid_t pid;
     int lastsig = 0;
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) && defined(__FreeBSD_USE_KVM)
     dropprivs();
 #endif
 
@@ -842,6 +842,7 @@ static void optmerge(struct query *h2, struct query *h1, int force)
     FLAG_MERGE(server.dns);
     FLAG_MERGE(server.checkalias);
     FLAG_MERGE(server.uidl);
+    FLAG_MERGE(server.principal);
 
 #if defined(linux) || defined(__FreeBSD__)
     FLAG_MERGE(server.interface);
@@ -1146,68 +1147,71 @@ static int load_params(int argc, char **argv, int optind)
 		/* prevent core dump from ill-formed or duplicate entry */
 		if (!leadname)
 		{
-		    report(stderr, 
-			   _("Lead server has no name.\n"));
+		    report(stderr, _("Lead server has no name.\n"));
 		    exit(PS_SYNTAX);
 		}
 
 		ctl->server.truename = xstrdup(leadname);
 	    }
 #ifdef HAVE_GETHOSTBYNAME
-	    else if (!configdump && (ctl->server.preauthenticate==A_KERBEROS_V4 ||
-		ctl->server.preauthenticate==A_KERBEROS_V5 ||
-		      (ctl->server.dns && MULTIDROP(ctl))))
+	    else if (!configdump)
 	    {
-		struct hostent	*namerec;
-
-		/* compute the canonical name of the host */
-		errno = 0;
-		namerec = gethostbyname(ctl->server.queryname);
-		if (namerec == (struct hostent *)NULL)
+		if (ctl->server.preauthenticate==A_KERBEROS_V4 ||
+		      ctl->server.preauthenticate==A_KERBEROS_V5 ||
+		    (ctl->server.dns && MULTIDROP(ctl)))
 		{
-		    report(stderr,
-			  _("couldn't find canonical DNS name of %s\n"),
-			  ctl->server.pollname);
-		    ctl->active = FALSE;
+		    struct hostent	*namerec;
+
+		    /* compute the canonical name of the host */
+		    errno = 0;
+		    namerec = gethostbyname(ctl->server.queryname);
+		    if (namerec == (struct hostent *)NULL)
+		    {
+			report(stderr,
+			       _("couldn't find canonical DNS name of %s\n"),
+			       ctl->server.pollname);
+			ctl->server.truename = xstrdup(ctl->server.queryname);
+			ctl->server.trueaddr = NULL;
+		    }
+		    else
+			ctl->server.truename=xstrdup((char *)namerec->h_name);
 		}
-		else
-		    ctl->server.truename=xstrdup((char *)namerec->h_name);
-	    }
 #endif /* HAVE_GETHOSTBYNAME */
-	    else {
+		else {
 #ifdef HAVE_GETHOSTBYNAME
-	      struct hostent	*namerec;
+		    struct hostent	*namerec;
+		    
+		    /* <fetchmail@mail.julianhaight.com>
+		       Get the host's IP, so we can report it like this:
 
-	      /* <fetchmail@mail.julianhaight.com>
-		 Get the host's IP, so we can report it like this:
+		       Received: from hostname [10.0.0.1]
 
-		 Received: from hostname [10.0.0.1]
-
-		 do we actually need to gethostbyname to find the IP?
-		 it seems like it would be faster to do this later, when
-		 we are actually resolving the hostname for a connection,
-		 but I ain't that smart, so I don't know where to make
-		 the change later..
-	      */
-	      errno = 0;
-	      namerec = gethostbyname(ctl->server.queryname);
-	      if (namerec == (struct hostent *)NULL)
-		{
-		  report(stderr,
-			 _("couldn't find canonical DNS name of %s\n"),
-			 ctl->server.pollname);
-		  exit(PS_DNS);
-		}
-	      else {
-		ctl->server.truename=xstrdup((char *)namerec->h_name);
-		ctl->server.trueaddr=xmalloc(namerec->h_length);
-		memcpy(ctl->server.trueaddr, 
-		       namerec->h_addr_list[0],
-		       namerec->h_length);
-	      }
+		       do we actually need to gethostbyname to find the IP?
+		       it seems like it would be faster to do this later, when
+		       we are actually resolving the hostname for a connection,
+		       but I ain't that smart, so I don't know where to make
+		       the change later..
+		    */
+		    errno = 0;
+		    namerec = gethostbyname(ctl->server.queryname);
+		    if (namerec == (struct hostent *)NULL)
+		    {
+			report(stderr,
+			       _("couldn't find canonical DNS name of %s\n"),
+			       ctl->server.pollname);
+			exit(PS_DNS);
+		    }
+		    else {
+			ctl->server.truename=xstrdup((char *)namerec->h_name);
+			ctl->server.trueaddr=xmalloc(namerec->h_length);
+			memcpy(ctl->server.trueaddr, 
+			       namerec->h_addr_list[0],
+			       namerec->h_length);
+		    }
 #else
-	      ctl->server.truename = xstrdup(ctl->server.queryname);
+		    ctl->server.truename = xstrdup(ctl->server.queryname);
 #endif /* HAVE_GETHOSTBYNAME */
+		}
 	    }
 
 	    /* if no folders were specified, set up the null one as default */
@@ -1479,6 +1483,8 @@ static void dump_params (struct runctl *runp,
 #endif
     if (runp->invisible)
 	printf(_("Fetchmail will masquerade and will not generate Received\n"));
+    if (runp->showdots)
+	printf(_("Fetchmail will show progress dots even in logfiles\n"));
     if (runp->postmaster)
 	printf(_("Fetchmail will forward misaddressed multidrop messages to %s.\n"),
 	       runp->postmaster);
@@ -1566,6 +1572,9 @@ static void dump_params (struct runctl *runp,
 	    printf(_("  Kerberos V5 preauthentication enabled.\n"));
 	else if (ctl->server.preauthenticate == A_SSH)
 	    printf(_("  End-to-end encryption assumed.\n"));
+	if (ctl->server.principal != (char *) NULL) {
+	    printf(_("  Mail service principal is: %s\n"), ctl->server.principal);
+	}
 #ifdef	SSL_ENABLE
 	if (ctl->use_ssl)
 	    printf("  SSL encrypted sessions enabled.\n");
