@@ -118,6 +118,7 @@ struct runctl
     char	*properties;
     flag	use_syslog;
     flag	invisible;
+    flag	showdots;
 };
 
 struct idlist
@@ -206,6 +207,7 @@ struct hostdata		/* shared among all user connections to given server */
     flag sdps;				/* use Demon Internet SDPS *ENV */
 #endif /* SDPS_ENABLE */
     flag checkalias;                  	/* resolve aliases by comparing IPs? */
+    char *principal;			/* Kerberos principal for mail service */
 
 
 #if defined(linux) || defined(__FreeBSD__)
@@ -496,7 +498,15 @@ char *xstrdup(const char *);
  #pragma alloca
 #endif
 #endif
-#define	xalloca(ptr, t, n)	if (!(ptr = (t) alloca(n))) {report(stderr, "alloca failed"); exit(PS_UNDEFINED);}
+#define	xalloca(ptr, t, n)	if (!(ptr = (t) alloca(n)))\
+       {report(stderr, _("alloca failed")); exit(PS_UNDEFINED);}
+#if FALSE
+/*
+ * This is a hack to help xgettext which cannot find strings in
+ * macro definitions like the one for xalloca above.
+ */
+static char *dummy = gettext_noop("alloca failed");
+#endif
 
 /* protocol driver and methods */
 int do_protocol(struct query *, const struct method *);
@@ -552,4 +562,16 @@ char *strerror ();
 #endif
 #endif
 
+#ifdef FETCHMAIL_DEBUG
+#define exit(e) do { \
+       FILE *out; \
+       out = fopen("/tmp/fetchmail.log", "a"); \
+       fprintf(out, \
+               "Exiting fetchmail from file %s, line %d with status %d\n", \
+               __FILE__, __LINE__, e); \
+       fclose(out); \
+       _exit(e); \
+       } while(0)
+#endif /* FETCHMAIL_DEBUG */
+
 /* fetchmail.h ends here */
