@@ -78,6 +78,9 @@
 #define LA_SSLCERT	52
 #endif
 
+#define LA_SHOWDOTS	53
+#define LA_PRINCIPAL	54
+
 /* options still left: CDgGhHjJoORwWxXYz */
 static const char *shortoptions = 
 	"?Vcsvd:NqL:f:i:p:UP:A:t:E:Q:u:akKFnl:r:S:Z:b:B:e:m:T:I:M:yw:";
@@ -94,6 +97,7 @@ static const struct option longoptions[] = {
   {"quit",	no_argument,	   (int *) 0, LA_QUIT        },
   {"logfile",	required_argument, (int *) 0, LA_LOGFILE     },
   {"invisible",	no_argument,	   (int *) 0, LA_INVISIBLE   },
+  {"showdots",	no_argument,	   (int *) 0, LA_SHOWDOTS    },
   {"syslog",	no_argument,	   (int *) 0, LA_SYSLOG      },
   {"nosyslog",	no_argument,	   (int *) 0, LA_NOSYSLOG    },
   {"fetchmailrc",required_argument,(int *) 0, LA_RCFILE      },
@@ -144,6 +148,8 @@ static const struct option longoptions[] = {
   {"sslcert",   required_argument, (int *) 0, LA_SSLCERT    },
 #endif
 
+  {"principal", required_argument, (int *) 0, LA_PRINCIPAL },
+
 #if (defined(linux) && !INET6_ENABLE) || defined(__FreeBSD__)
   {"interface",	required_argument, (int *) 0, LA_INTERFACE   },
   {"monitor",	required_argument, (int *) 0, LA_MONITOR     },
@@ -299,6 +305,9 @@ struct query *ctl;	/* option record to be initialized */
 	case LA_INVISIBLE:
 	    rctl->invisible = TRUE;
 	    break;
+	case LA_SHOWDOTS:
+	    rctl->showdots = TRUE;
+	    break;
 	case 'f':
 	case LA_RCFILE:
 	    rcfile = (char *) xstrdup(optarg);
@@ -553,6 +562,10 @@ struct query *ctl;	/* option record to be initialized */
 	    break;
 #endif
 
+	case LA_PRINCIPAL:
+	    ctl->server.principal = xstrdup(optarg);
+	    break;
+
 	case 'y':
 	case LA_YYDEBUG:
 	    yydebug = TRUE;
@@ -623,6 +636,7 @@ struct query *ctl;	/* option record to be initialized */
 	P(_("  -t, --timeout     server nonresponse timeout\n"));
 	P(_("  -E, --envelope    envelope address header\n"));
 	P(_("  -Q, --qvirtual    prefix to remove from local user id\n"));
+	P(_("      --principal   mail service principal\n"));
 
 	P(_("  -u, --username    specify users's login on server\n"));
 	P(_("  -a, --all         retrieve old and new messages\n"));
@@ -647,6 +661,7 @@ struct query *ctl;	/* option record to be initialized */
         P(_("      --bsmtp       set output BSMTP file\n"));
         P(_("      --lmtp        use LMTP (RFC2033) for delivery\n"));
 	P(_("  -r, --folder      specify remote folder name\n"));
+	P(_("      --showdots    show progress dots even in logfiles\n"));
 #undef P
 
 	if (helpflag)
