@@ -803,6 +803,10 @@ int open_sink(struct query *ctl, struct msgblk *msg,
 		else
 		{
 		    char	errbuf[POPBUFSIZE];
+		    int res;
+
+		    if ((res = handle_smtp_report(ctl, msg))==PS_REFUSED)
+			return PS_REFUSED;
 
 		    strcpy(errbuf, idp->id);
 		    strcat(errbuf, ": ");
